@@ -1,14 +1,14 @@
 package Complete::Module;
 
-our $DATE = '2015-10-08'; # DATE
-our $VERSION = '0.22'; # VERSION
+our $DATE = '2015-11-29'; # DATE
+our $VERSION = '0.23'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
 #use Log::Any '$log';
 
-use Complete::Setting;
+use Complete::Common qw(:all);
 use List::MoreUtils qw(uniq);
 
 our %SPEC;
@@ -76,19 +76,7 @@ autoselection of path separator character, some shortcuts, and so on.
 
 _
     args => {
-        word => {
-            schema => 'str*',
-            req => 1,
-            pos => 0,
-        },
-        ci => {
-            summary => 'Whether to do case-insensitive search',
-            schema  => 'bool*',
-        },
-        fuzzy => {
-            summary => 'Whether to do fuzzy matching',
-            schema  => ['int*', min=>0],
-        },
+        %arg_word,
         path_sep => {
             summary => 'Path separator',
             schema  => 'str*',
@@ -102,15 +90,6 @@ to avoid word-breaking by bash.
 
 _
         },
-        map_case => {
-            schema => 'bool',
-        },
-        exp_im_path => {
-            schema => 'bool',
-        },
-        dig_leaf => {
-            schema => 'bool',
-        },
         find_pm => {
             summary => 'Whether to find .pm files',
             schema  => 'bool*',
@@ -156,11 +135,6 @@ sub complete_module {
     #$log->tracef('[compmod] Entering complete_module(), word=<%s>', $word);
     #$log->tracef('[compmod] args=%s', \%args);
 
-    my $ci          = $args{ci} // $Complete::Setting::OPT_CI;
-    my $fuzzy       = $args{fuzzy} // $Complete::Setting::OPT_FUZZY;
-    my $map_case    = $args{map_case} // $Complete::Setting::OPT_MAP_CASE;
-    my $exp_im_path = $args{exp_im_path} // $Complete::Setting::OPT_EXP_IM_PATH;
-    my $dig_leaf    = $args{dig_leaf} // $Complete::Setting::OPT_DIG_LEAF;
     my $ns_prefix = $args{ns_prefix} // '';
     $ns_prefix =~ s/(::)+\z//;
 
@@ -200,13 +174,6 @@ sub complete_module {
     #$log->tracef('[compmod] invoking complete_path, word=<%s>', $word);
     my $res = Complete::Path::complete_path(
         word => $word,
-
-        ci => $ci,
-        fuzzy => $fuzzy,
-        map_case => $map_case,
-        exp_im_path => $exp_im_path,
-        dig_leaf=>$dig_leaf,
-
         starting_path => $ns_prefix,
         list_func => sub {
             my ($path, $intdir, $isint) = @_;
@@ -255,7 +222,7 @@ Complete::Module - Complete with installed Perl module names
 
 =head1 VERSION
 
-This document describes version 0.22 of Complete::Module (from Perl distribution Complete-Module), released on 2015-10-08.
+This document describes version 0.23 of Complete::Module (from Perl distribution Complete-Module), released on 2015-11-29.
 
 =head1 SYNOPSIS
 
@@ -324,14 +291,6 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<ci> => I<bool>
-
-Whether to do case-insensitive search.
-
-=item * B<dig_leaf> => I<bool>
-
-=item * B<exp_im_path> => I<bool>
-
 =item * B<find_pm> => I<bool> (default: 1)
 
 Whether to find .pm files.
@@ -348,12 +307,6 @@ Whether to find .pod files.
 
 Whether to find module prefixes.
 
-=item * B<fuzzy> => I<int>
-
-Whether to do fuzzy matching.
-
-=item * B<map_case> => I<bool>
-
 =item * B<ns_prefix> => I<str>
 
 Namespace prefix.
@@ -374,7 +327,9 @@ default to C</>. This is because C<::> (contains colon) is rather problematic as
 it is by default a word-break character in bash and the word needs to be quoted
 to avoid word-breaking by bash.
 
-=item * B<word>* => I<str>
+=item * B<word>* => I<str> (default: "")
+
+Word to complete.
 
 =back
 
@@ -386,7 +341,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Complete-M
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Complete-Module>.
+Source repository is at L<https://github.com/sharyanto/perl-Complete-Module>.
 
 =head1 BUGS
 
